@@ -5,10 +5,10 @@ from quickstats.components.analysis_object import AnalysisObject
 from quickstats.components.asimov_generator import AsimovGenerator
 from quickstats.components.asimov_generator import AsimovType
 from quickstats.components.nuisance_parameter_pull import NuisanceParameterPull
-from quickstats.components.roofit_plotter import RooFitPlotter
 from quickstats.components.nuisance_parameter_harmonizer import NuisanceParameterHarmonizer
 from quickstats.components.asymptotic_cls import AsymptoticCLs
 from quickstats.components.likelihood import Likelihood
 from quickstats.components.pvalue_toys import PValueToys
 from quickstats.components.toy_limit_calculator import ToyLimitCalculator
-from quickstats.components.analysis_base import AnalysisBase
\ No newline at end of file
+from quickstats.components.analysis_base import AnalysisBase
+from quickstats.components.param_parser import ParamParser
\ No newline at end of file
