@@ -105,13 +105,10 @@ class ExtendedModel(AbstractObject):
     
     @semistaticmethod
     def load_extension(self):
-        try:
-            for extension in ['RooTwoSidedCBShape', 'FlexibleInterpVarMkII']:
-                result = load_macro(extension)
-                if (result is not None) and hasattr(ROOT, extension):
-                    self.stdout.info(f'INFO: Loaded extension module "{extension}"')    
-        except Exception as e:
-            print(e)
+        for extension in ['RooTwoSidedCBShape', 'FlexibleInterpVarMkII']:
+            result = load_macro(extension)
+            if (result is not None) and hasattr(ROOT, extension):
+                self.stdout.info(f'INFO: Loaded extension module "{extension}"')
             
     @staticmethod
     def load_RooFitObjects():
@@ -254,8 +251,8 @@ class ExtendedModel(AbstractObject):
         nuisance_parameters = model_config.GetNuisanceParameters()
         if not nuisance_parameters:
             #raise RuntimeError('Failed to load nuisance parameters')
-            self.stdout.info("WARNING: No nuisance parameters found in the workspace. "
-                         "An empty set will be loaded by default.")
+            self.stdout.warning("WARNING: No nuisance parameters found in the workspace. "
+                                "An empty set will be loaded by default.")
             nuisance_parameters = ROOT.RooArgSet()
         else:
             self.stdout.info('INFO: Loaded nuisance parameters from model config')
@@ -263,8 +260,11 @@ class ExtendedModel(AbstractObject):
         # Load global observables
         global_observables = model_config.GetGlobalObservables()
         if not global_observables:
-            raise RuntimeError('Failed to load global observables')          
-        self.stdout.info('INFO: Loaded global observables from model config')                  
+            self.stdout.warning("WARNING: No nuisance parameters found in the workspace. "
+                                "An empty set will be loaded by default.")            
+            global_observables = ROOT.RooArgSet()
+        else:
+            self.stdout.info('INFO: Loaded global observables from model config')                  
     
         # Load POIs
         pois = model_config.GetParametersOfInterest()
