@@ -30,4 +30,8 @@ def get_all_macros():
     macros_dir = os.path.join(quickstats.macro_path, 'macros')
     macro_paths = glob.glob(os.path.join(macros_dir, "*.cxx"))
     macros = [os.path.os.path.splitext(os.path.basename(path))[0] for path in macro_paths]
-    return macros
\ No newline at end of file
+    return macros
+
+
+def set_verbosity(verbosity:Union[str, int]="INFO"):
+    quickstats._PRINT_.verbosity = verbosity
\ No newline at end of file
